-- 用户信息主表
CREATE TABLE webchat_user.`web_chat_user` (
     `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
     `USER_ID` char(60) NOT NULL COMMENT '用户ID',
     `USER_NAME` char(30) NOT NULL COMMENT '用户名',
     `PHOTO` varchar(400) NOT NULL COMMENT '用户头像',
     `MOBILE` char(20) NOT NULL COMMENT '手机号',
     `PASSWORD` char(100) NOT NULL COMMENT '密码',
     `SIGNATURE` varchar(500) DEFAULT '暂无签名' COMMENT '签名',
     `STATUS` INT NOT NULL DEFAULT 1 COMMENT '用户状态状态',
     `ROLE_CODE` INT NOT NULL DEFAULT 1 COMMENT '角色',
     `CREATE_BY` char(100) DEFAULT NULL COMMENT '创建人',
     `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
     `UPDATE_BY` char(100) DEFAULT NULL COMMENT '更新人',
     `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
     `VERSION` int DEFAULT '0' COMMENT '版本',
     PRIMARY KEY (`ID`),
     KEY `INDEX_USER_ID` (`USER_ID`),
     KEY `INDEX_MOBILE_PASSWORD` (`MOBILE`, `PASSWORD`),
     KEY `INDEX_STATUS` (`STATUS`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='用户信息主表';

-- 初始化默认管理员账号
INSERT INTO `webchat_user`.`web_chat_user` (`ID`, `USER_ID`, `USER_NAME`, `PHOTO`, `MOBILE`, `PASSWORD`, `STATUS`, `ROLE_CODE`,
                                       `CREATE_BY`, `CREATE_DATE`, `UPDATE_BY`, `UPDATE_DATE`, `VERSION`) VALUES
    (1, 'U_770cce9f632543588b4e8aa6ec43e6a2', '管理员', 'https://coderutil.oss-cn-beijing.aliyuncs.com/bbs-image/file_dd489633f1bb4513a9db81be6e9d692f.png',
     'admin', '06525f4969c6cf1886ee0db86bef82df', 1, 2, 'U_770cce9f632543588b4e8aa6ec43e6a2',
     '2022-03-12 05:55:26', NULL, '2022-03-22 10:28:38', 1);
-- 初始化文件传输助手
INSERT INTO `webchat_user`.`web_chat_user` (`USER_ID`, `USER_NAME`, `PHOTO`, `MOBILE`, `PASSWORD`, `STATUS`, `ROLE_CODE`,
                                            `CREATE_BY`, `CREATE_DATE`, `UPDATE_BY`, `UPDATE_DATE`, `VERSION`) VALUES
    ('F_ef352f698ad7b60c1d8a3aaa4a948030', '文件传输助手', 'https://coderutil.oss-cn-beijing.aliyuncs.com/bbs-image/file_42a26236a73f4df8b742397ac9c46c4f.png',
     'filesender', 'F_ef352f698ad7b60c1d8a3aaa4a948030', 1, 0, 'F_ef352f698ad7b60c1d8a3aaa4a948030',
     '2022-03-12 05:55:26', NULL, '2022-03-22 10:28:38', 1);

-- 好友关系表
CREATE TABLE webchat_user.`web_chat_friend` (
   `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
   `USER_ID` char(60) NOT NULL COMMENT '用户ID',
   `FRIEND_ID` char(60) NOT NULL COMMENT '好友ID',
   `STATUS` int(11) DEFAULT '0' COMMENT '好友状态',
   `APPLY_DATE` datetime DEFAULT NULL COMMENT '申请时间',
   `HANDLE_DATE` datetime DEFAULT NULL COMMENT '处理时间',
   `VERSION` int DEFAULT '0' COMMENT '版本',
   PRIMARY KEY (`ID`),
   KEY `INDEX_USER_ID` (`USER_ID`),
   KEY `INDEX_FRIEND_ID` (`FRIEND_ID`),
   KEY `INDEX_STATUS` (`STATUS`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='好友关系表';


-- 群组用户表
CREATE TABLE webchat_user.`web_chat_group_user` (
                                       `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                       `GROUP_ID` char(60) NOT NULL COMMENT '群组ID',
                                       `USER_ID` char(60) NOT NULL COMMENT '用户ID',
                                       `STATUS` INT NOT NULL DEFAULT 1 COMMENT '用户状态状态',
                                       `CREATE_BY` char(100) DEFAULT NULL COMMENT '创建人',
                                       `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                       `UPDATE_BY` char(100) DEFAULT NULL COMMENT '更新人',
                                       `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
                                       `VERSION` int DEFAULT '0' COMMENT '版本',
                                       PRIMARY KEY (`ID`),
                                       KEY `INDEX_GROUP_ID` (`GROUP_ID`),
                                       KEY `INDEX_USER_ID` (`USER_ID`),
                                       KEY `INDEX_STATUS` (`STATUS`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='群组用户表';


-- 账号关系表
CREATE TABLE webchat_user.`web_chat_account_relation` (
  `id` bigint NOT NULL AUTO_INCREMENT COMMENT '关系主键',
  `source_account` char(64) NOT NULL COMMENT '原账号',
  `target_account` char(64) NOT NULL COMMENT '目标账号',
  `type` int(4) NOT NULL COMMENT '关系类型',
  `status` int(4) NOT NULL COMMENT '关系状态',
  `create_date` date NOT NULL COMMENT '创建时间',
  `update_date` date NOT NULL COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `UK_IDX_SOURCE_TARGET_ACCOUNT`(source_account, target_account),
  KEY `IDX_STATUS_TYPE`(status, type)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='账号关系表';